#' @details
#'
#' \describe{
#'   \item{Homepage:}{\url{https://github.com/mllg/checkmate}}
#' }
#' @importFrom utils head
#' @importFrom utils tail
"_PACKAGE"
